@@ -159,15 +159,18 @@
 ##' \dontrun{polarFreq(mydata, pollutant = "so2", type = "year", statistic = "mean", min.bin = 2)}
 ##'
 ##' # weighted mean SO2 by year, showing only bins with at least 2 points
-##' \dontrun{polarFreq(mydata, pollutant = "so2", type = "year", statistic = "weighted.mean", min.bin = 2)}
+##' \dontrun{polarFreq(mydata, pollutant = "so2", type = "year", statistic = "weighted.mean",
+##' min.bin = 2)}
 ##'
 ##' #windRose for just 2000 and 2003 with different colours
-##' \dontrun{polarFreq(subset(mydata, format(date, "%Y") %in% c(2000, 2003)), type = "year", cols = "jet")}
+##' \dontrun{polarFreq(subset(mydata, format(date, "%Y") %in% c(2000, 2003)),
+##' type = "year", cols = "jet")}
 ##'
 ##' # user defined breaks from 0-700 in intervals of 100 (note linear scale)
 ##' \dontrun{polarFreq(mydata, breaks = seq(0, 700, 100))}
 ##'
-##' # more complicated user-defined breaks - useful for highlighting bins with a certain number of data points
+##' # more complicated user-defined breaks - useful for highlighting bins
+##' # with a certain number of data points
 ##' \dontrun{polarFreq(mydata, breaks = c(0, 10, 50, 100, 250, 500, 700))}
 ##'
 ##' # source contribution plot and use of offset option
@@ -197,7 +200,7 @@ polarFreq <- function(mydata,
 
     ## extract necessary data
     vars <- c("wd", "ws")
-    if (any(type %in%  openair:::dateTypes)) vars <- c(vars, "date")
+    if (any(type %in%  dateTypes)) vars <- c(vars, "date")
 
     ## greyscale handling
     if (length(cols) == 1 && cols == "greyscale") {
@@ -223,7 +226,7 @@ polarFreq <- function(mydata,
     if (!missing(pollutant)) vars <- c(vars, pollutant)
 
     ## data checks
-    mydata <- openair:::checkPrep(mydata, vars, type, remove.calm = FALSE)
+    mydata <- checkPrep(mydata, vars, type, remove.calm = FALSE)
 
     ## to make first interval easier to work with, set ws = 0 + e
     ids <- which(mydata$ws == 0)
@@ -336,7 +339,7 @@ polarFreq <- function(mydata,
     results.grid <- na.omit(results.grid)
 
     ## proper names of labelling ###################################################
-    strip.dat <- openair:::strip.fun(results.grid, type, auto.text)
+    strip.dat <- strip.fun(results.grid, type, auto.text)
     strip <- strip.dat[[1]]
     strip.left <- strip.dat[[2]]
     pol.name <- strip.dat[[3]]
@@ -373,7 +376,7 @@ polarFreq <- function(mydata,
                    space = key.position,
                    auto.text = auto.text, footer = key.footer, header = key.header,
                    height = 1, width = 1.5, fit = "all")
-    legend <- openair:::makeOpenKeyLegend(key, legend, "polarFreq")
+    legend <- makeOpenKeyLegend(key, legend, "polarFreq")
 
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("ws ~ wd | ", temp, sep = ""))
@@ -432,7 +435,7 @@ polarFreq <- function(mydata,
                   )
 
     #reset for extra.args
-    xyplot.args<- openair:::listUpdate(xyplot.args, extra.args)
+    xyplot.args<- listUpdate(xyplot.args, extra.args)
 
     #plot
     plt <- do.call(xyplot, xyplot.args)
@@ -441,7 +444,7 @@ polarFreq <- function(mydata,
 #################
     ## output
 #################
-    if (length(type) == 1) plot(plt) else plot(openair:::useOuterStrips(plt, strip = strip, strip.left = strip.left))
+    if (length(type) == 1) plot(plt) else plot(useOuterStrips(plt, strip = strip, strip.left = strip.left))
     newdata <- results.grid
     output <- list(plot = plt, data = newdata, call = match.call())
     class(output) <- "openair"
